@@ -22,8 +22,8 @@ class MiddlewareBase(ABC):
 class LocalAuthentication(MiddlewareBase):
     """Local authentication"""
 
-    def __init__(self, username, password, login_method):
-        self.client = AuthenticationHandler()
+    def __init__(self, username, password, login_method, show_window=False):
+        self.client = AuthenticationHandler(show_window)
         self.client.set_credentials({
             'username': username,
             'password': password,
